@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-import functools
+import functools,warnings
 
 from django.conf import settings
 from django.core.cache.backends.base import BaseCache
@@ -22,13 +22,13 @@ def omit_exception(method):
 
     @functools.wraps(method)
     def _decorator(self, *args, **kwargs):
-        if self._ignore_exceptions:
-            try:
-                return method(self, *args, **kwargs)
-            except ConnectionInterrupted:
-                return None
-        else:
+        try:
             return method(self, *args, **kwargs)
+        except ConnectionInterrupted as e:
+            if self._ignore_exceptions:
+                return None
+
+            raise e.parent
 
     return _decorator
 
@@ -62,6 +62,8 @@ class RedisCache(BaseCache):
         pluggable clients supports this feature. If not supports
         this raises NotImplementedError
         """
+        warnings.warn("raw_client is deprecated. use self.client.get_client instead",
+                                  DeprecationWarning, stacklevel=2)
         return self.client.get_client(write=True)
 
     @omit_exception
